@@ -69,7 +69,7 @@ class Format(GObject.Object):
 
     @property
     def requires_texlive(self):
-        return self.ext in {"tex", "pdf"} and self.engine != "typst"
+        return self.ext in {"tex", "pdf"} and self.engine != "weasyprint"
 
 
 class ExportDialog:
@@ -83,7 +83,7 @@ class ExportDialog:
             "extension": "pdf",
             "to": "pdf",
             "mimetype": "application/pdf",
-            "args": ["--pdf-engine=xelatex",
+            "args": ["--pdf-engine=weasyprint",
                      "--variable=papersize:a4"]
         },
         "html":
@@ -242,7 +242,7 @@ class AdvancedExportDialog(Adw.Dialog):
 
     @GObject.Property(type=bool, default=False)
     def show_syntax_options(self):
-        return self.formats_list.get_selected_row().item.has_syntax and self.formats_list.get_selected_row().item.engine != "typst"
+        return self.formats_list.get_selected_row().item.has_syntax
 
     @GObject.Property(type=bool, default=False)
     def show_presentation_options(self):
@@ -345,8 +345,6 @@ class AdvancedExportDialog(Adw.Dialog):
 
         if self.formats_list.get_selected_row().item.ext == "pdf":
             args.append(f"--pdf-engine={self.formats_list.get_selected_row().item.engine}")
-            if self.formats_list.get_selected_row().item.engine == "typst":
-                args.extend(['-V', 'template=%s' % helpers.get_media_path('/pandoc_templates/typst.typ')])
 
         if self.sw_standalone.get_active():
             args.append("--standalone")
